@@ -1,10 +1,10 @@
-from abc import ABC, abstractmethod
+from abc import ABCMeta, abstractmethod
 from typing import Union, Any
 from pathlib import Path
 import pickle
 
 
-class _FileEngine(ABC):
+class _FileEngine(metaclass=ABCMeta):
 
     """
     Abstract class from which all file-based engine classes inherit.
@@ -26,7 +26,7 @@ class _FileEngine(ABC):
 
 
 class PickleEngine(_FileEngine):
-    
+
     """
     Class that enables to read and write to pickle files.
 
@@ -35,7 +35,7 @@ class PickleEngine(_FileEngine):
     """
 
     def __init__(self, filepath: Union[str, Path]):
-      
+
         super().__init__()
         self.filepath = filepath
 
@@ -56,6 +56,6 @@ class PickleEngine(_FileEngine):
         Args:
             obj: object to be pickled.
         """
-        
-        with open(self.filepath, 'wb') as file:
+
+        with open(self.filepath, "wb") as file:
             pickle.dump(obj, file, protocol=pickle.HIGHEST_PROTOCOL)
